@@ -1,12 +1,12 @@
 /* glpgel/gel.c */
 
 /*----------------------------------------------------------------------
--- This file is a part of the GNU LPK package.
+-- This file is a part of the GLPK package.
 --
--- Copyright (C) 2000 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                    Department for Applied Informatics,
---                    Moscow Aviation Institute, Moscow, Russia.
---                    All rights reserved.
+-- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
+--                          Department for Applied Informatics,
+--                          Moscow Aviation Institute, Moscow, Russia.
+--                          All rights reserved.
 --
 -- This code is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -238,7 +238,7 @@ int gel(MAT *_V, PER *_P, PER *_Q,
       Unz = *_Unz; Umax = 0.0; Ubig = 0.0;
       rs = _rs; cs = _cs; rmax = _rmax; work = _work;
       if (V->m != V->n)
-         fault("gel: transformed matrix is not quadratic");
+         fault("gel: transformed matrix is not square");
       if (!(P->n == n && Q->n == n))
          fault("gel: permutation matrices have invalid order");
       /* reset permutation matrices, because initially U = V */
@@ -688,7 +688,7 @@ static void eliminate(ELEM *piv)
             during elimination */
          if (Ubig < big) Ubig = big;
          /* i-th row of the matrix V has been transformed */
-         func(iU(i), k, f);
+         if (func != NULL) func(iU(i), k, f);
       }
       /* now all zeros appeared in the active submatrix as a result of
          elimination should be removed */
