@@ -1,12 +1,12 @@
 /* glpmat.h */
 
 /*----------------------------------------------------------------------
--- This file is a part of the GNU LPK package.
+-- This file is a part of the GLPK package.
 --
--- Copyright (C) 2000 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                    Department for Applied Informatics,
---                    Moscow Aviation Institute, Moscow, Russia.
---                    All rights reserved.
+-- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
+--                          Department for Applied Informatics,
+--                          Moscow Aviation Institute, Moscow, Russia.
+--                          All rights reserved.
 --
 -- This code is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@
 #define inv_per               glp_inv_per
 #define iper_vec              glp_iper_vec
 #define l_solve               glp_l_solve
+#define load_mat              glp_load_mat
 #define lt_solve              glp_lt_solve
 #define mat_per               glp_mat_per
 #define mat_vec               glp_mat_vec
@@ -53,12 +54,15 @@
 #define mprd_symb             glp_mprd_symb
 #define new_elem              glp_new_elem
 #define per_mat               glp_per_mat
+#define per_sym               glp_per_sym
 #define per_vec               glp_per_vec
 #define reset_per             glp_reset_per
+#define save_mat              glp_save_mat
 #define scrape_mat            glp_scrape_mat
 #define show_mat              glp_show_mat
 #define sort_mat              glp_sort_mat
 #define submatrix             glp_submatrix
+#define sym_vec               glp_sym_vec
 #define test_mat_d            glp_test_mat_d
 #define test_mat_e            glp_test_mat_e
 #define tmat_vec              glp_tmat_vec
@@ -171,6 +175,9 @@ extern double *iper_vec(double y[], PER *P, double x[]);
 extern double *l_solve(MAT *L, double x[]);
 /* solve lower triangular system L*x = b */
 
+extern MAT *load_mat(char *fname);
+/* read sparse matrix from text file using plain format */
+
 extern double *lt_solve(MAT *L, double x[]);
 /* solve transposed lower triangular system L'*x = b */
 
@@ -192,12 +199,18 @@ extern ELEM *new_elem(MAT *A, int i, int j, double val);
 extern MAT *per_mat(PER *P, MAT *A, void *work[]);
 /* permute matrix rows (A := P * A) */
 
+extern MAT *per_sym(PER *P, MAT *A, void *work[]);
+/* permute symmetric matrix (A := P*A*P') */
+
 extern double *per_vec(double y[], PER *P, double x[]);
 /* permute vector elements (y := P * x) */
 
 extern PER *reset_per(PER *P);
 /* reset permutation matrix (P := I) */
 
+extern int save_mat(MAT *A, char *fname);
+/* write sparse matrix to text file using plain format */
+
 extern int scrape_mat(MAT *A, double eps);
 /* remove tiny elements from sparse matrix */
 
@@ -210,6 +223,9 @@ extern MAT *sort_mat(MAT *A);
 extern MAT *submatrix(MAT *B, MAT *A, int i1, int i2, int j1, int j2);
 /* copy submatrix */
 
+extern double *sym_vec(double y[], MAT *A, double x[]);
+/* multiply symmetric matrix on vector (y := A * x) */
+
 extern MAT *test_mat_d(int n, int c);
 /* create test sparse matrix of D(n,c) class */
 
