@@ -1,12 +1,12 @@
 /* glpstr.h */
 
 /*----------------------------------------------------------------------
--- This file is a part of the GNU LPK package.
+-- This file is a part of the GLPK package.
 --
--- Copyright (C) 2000 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                    Department for Applied Informatics,
---                    Moscow Aviation Institute, Moscow, Russia.
---                    All rights reserved.
+-- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
+--                          Department for Applied Informatics,
+--                          Moscow Aviation Institute, Moscow, Russia.
+--                          All rights reserved.
 --
 -- This code is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
